@@ -13,7 +13,7 @@ class BaseSlides:
         self.__screenshot = ScreenShot(self.__widgets)
         self.clipboard_image = self.__screenshot.clipboard_image # For easy access
         self.__navigation = Navigation(self.__widgets) # Not accessed later, just for actions
-        self.__settings = LayoutSettings(self.__widgets)
+        self.__settings = LayoutSettings(self, self.__widgets)
         self.__export = _HhtmlExporter(self)
         self.__notes = Notes(self, self.__widgets) # Needs main class for access to notes
         
@@ -69,8 +69,8 @@ class BaseSlides:
         className = 'slides-only'       Text will not appear in exported html with `build_report`
         className = 'report-only'       Text will not appear on slides. Useful to fill content in report.
         className = 'Block'             Block of text/objects
-        className = 'Block-[color]'      Block of text/objects with specific background color from red, green, blue, yellow, cyan, magenta and gray.
-        ''',className= 'PyRepr')
+        className = 'Block-[color]'     Block of text/objects with specific background color from red, green, blue, yellow, cyan, magenta and gray.
+        ''',className= 'RawText')
         
     def get_source(self, title = 'Source Code'):
         "Return source code of all slides created using `from_markdown` or `%%slide`."
@@ -99,6 +99,9 @@ class BaseSlides:
             return f'Notification at {time}'
         ```
         """
+        if not self._running_slide:
+            raise RuntimeError('You can only use this decorator inside a slide constructor.')
+        
         def _notify(func): 
             self._running_slide._toast = dict(func = func, kwargs = dict(title=title, timeout=timeout))
         return _notify
@@ -217,6 +220,7 @@ class BaseSlides:
         """Demo slides with a variety of content."""
         self.close_view() # Close any previous view to speed up loading 10x faster on average
         self.clear() # Clear previous content
+        self._citation_mode = 'global' # Set citation mode to global if set otherwise by user
         
         import runpy
         file = os.path.join(os.path.dirname(os.path.dirname(__file__)), '_demo.py') # Relative path to this file
@@ -234,7 +238,7 @@ class BaseSlides:
             
         with slides.slide(N + 3, props_dict = {'': dict(background='#9ACD32')}):
             with slides.source.context() as s:
-                slides.write_citations()
+                slides.write('citations`## Reference via Markdown\n----`',['## Reference via Python API\n----',*slides.citations])
             s.display()
         
         # Just for func, set theme of all even slides to be fancy, and zoom animation
@@ -248,7 +252,7 @@ class BaseSlides:
             s.set_css({'slide': fancy_even_slides_css})
             s.set_animation('zoom')
         
-        slides._slideindex = 0 # Go to title
+        slides._slideindex = 0 # Go to title, user should not set this
         return slides
     
     def docs(self):
@@ -278,11 +282,11 @@ class BaseSlides:
                 ''').display()
             
         with self.slide(next(counter)):
-            self.write(self.doc(Slides))
+            self.write(['# Main App',self.doc(Slides)])
         
         with self.slide(next(counter)):
             self.write('## Adding Slides')
-            self.write('Besides functions below, you can add slides with `%%title`,  `%%slide <slide number>` and `%%slide <slide number>` -m`,`%%slide <slide number> -s` magics as well.\n{.Note .Info}')
+            self.write('Besides functions below, you can add slides with `%%title` magics as well.\n{.Note .Info}')
             self.write([self.doc(self.title,'Slides'),self.doc(self.slide,'Slides'),self.doc(self.frames,'Slides'),self.doc(self.from_markdown,'Slides')])
         
         with self.slide(next(counter)):
@@ -293,7 +297,8 @@ class BaseSlides:
         
         with self.slide(next(counter)):
             self.write('## Adding Speaker Notes')
-            self.write('You can use line magic `%notes` to add notes as well.\n{.Note .Success}')
+            self.write([f'You can use alert`notes{self.backtick}notes content{self.backtick}` in markdown.\n{{.Note .Success}}\n',
+                       'This is experimental feature, and may not work as expected.\n{.Block-red .Error}'])
             self.doc(self.notes,'Slides.notes', members = True, itself = False).display()
                    
         with self.slide(next(counter)):
@@ -302,15 +307,14 @@ class BaseSlides:
         
         with self.slide(next(counter)):
             self.write('## Layout and Theme Settings')
-            self.doc(self.glassmorphic,'Slides').display()
             self.doc(self.settings,'Slides.settings', members=True,itself = False).display()
                 
         with self.slide(next(counter)):
             self.write('## Useful Functions for Rich Content')
-            members = ['alert','block', 'bokeh2html', 'capture_std', 'citations_html', 'cite',
+            members = ['suppress_stdout','alert','block', 'bokeh2html', 'cite',
                        'colored', 'cols', 'details', 'doc','sub','sup', 'today', 'enable_zoom', 'format_css', 'format_html', 'highlight',
                        'html', 'iframe', 'image', 'keep_format', 'notify', 'notify_later', 'plt2html', 'raw', 'rows',
-                       'set_dir', 'sig', 'svg', 'textbox', 'vspace', 'write_citations', 'set_slide_css']
+                       'set_dir', 'sig', 'svg', 'textbox', 'vspace']
             self.doc(self.clipboard_image,'Slides').display()
             self.doc(self, 'Slides', members = members, itself = False).display()
             
@@ -325,7 +329,8 @@ class BaseSlides:
         
         s8, = self.from_markdown(next(counter), '''
         ## Highlighting Code
-        You can **highlight**{.Error} code using `highlight` function or within markdown like this:
+        [pyg]:`[pygments](https://pygments.org/) is used for syntax highlighting.`
+        You can **highlight**{.Error} code using `highlight`cite`pyg` function or within markdown like this:
         ```python
         import ipyslides as isd
         ```
@@ -339,6 +344,7 @@ class BaseSlides:
             self.write('<hr/>This slide was created with `from_markdown` function. '
                 'So its source code can be inserted in the slide later! '
                 'See at last slide how it was done!<hr/>')
+            self.write(s8.citations)
             s8.source.display()
         
         with self.slide(next(counter)):
@@ -358,7 +364,10 @@ class BaseSlides:
             self.doc(self.extender,'Slides.extender', members = True, itself = False).display()
         
         with self.slide(next(counter)):
-            self.write('## Keys and Shortcuts', key_combs)
+            self.write('## Keys and Shortcuts\n'
+                '- You can use `Slides.current` to access a slide currently in view.\n'
+                '- You can use `Slides.running` to access the slide currently being built,'
+                ' so you can set CSS, aminations etc.', key_combs)
         
         with self.slide(next(counter)):
             self.write(['## Presentation Code',self.docs])
