@@ -76,6 +76,7 @@ Launch example Notebook [![Binder](https://mybinder.org/badge_logo.svg)](https:/
 def func(obj):
     with slides.source.context() as s:
         slides.write(obj)
+        slides.write(slides.running) # This is currently running slide, so you can set CSS, animation etc inside the function.
         slides.notify_later()(lambda: 'That is a notification which shows you can use decorator this way as well')
     s.display()
 
@@ -229,8 +230,8 @@ def func(obj):
         ax.plot(x,np.sin(x));
         ax.set_title(f'$f(x)=\sin(x)$, 0 < x < {obj - 13}')
         ax.set_axis_off()
-        slides.notes.insert(f'## This is under @frames decorator, so it will be shown only in first frame')
-        slides.notify_later()(lambda: f'This is under @frames decorator, so it will be shown only in first frame')
+        slides.notes.insert(f'## This is under @frames decorator!')
+        slides.notify_later()(lambda: f'This is under @frames decorator!')
         
     slides.write([f'### This is Slide {14}.{obj-14}\n and we are animating matplotlib',
                   s.show_lines([obj-14])
@@ -299,7 +300,7 @@ with slides.slide(21):
     
 with slides.slide(22):
     slides.write('## Serialize Custom Objects to HTML\nThis is useful for displaying user defined/third party objects in slides')
-    with slides.capture_std():
+    with slides.suppress_stdout(): # suppress stdout from register fuction below
         with slides.source.context() as s:
             @slides.serializer.register(int)
             def colorize(obj):
@@ -307,5 +308,5 @@ with slides.slide(22):
                 return f'<span style="color:{color};">{obj}</span>'
 
             slides.write(*range(10))
-        
+
         s.display()
\ No newline at end of file
