@@ -19,8 +19,7 @@ _under_slides = {k:getattr(utils,k,None) for k in utils.__all__}
 from ._base.base import BaseSlides
 from ._base.intro import how_to_slide, logo_svg, key_combs
 from ._base.scripts import multi_slides_alert
-from ._base.slide import Slide, _build_slide, append_print_warning
-from ._base.styles import glass_css
+from ._base.slide import Slide, _build_slide
 
 try:  # Handle python IDLE etc.
     SHELL = get_ipython()
@@ -35,22 +34,26 @@ class _Citation:
         self._slide = slide
         self._key = key
         self._id = '?'
+        self._slide._citations[key] = self # Add to slide's citations
         
     def __repr__(self):
         return f"Citation(key = {self._key!r}, id = {self._id!r}, slide_label = {self._slide.label!r})"
     
-    @property
-    def html(self):
+    def __format__(self, spec):
+        return f'{self.value:{spec}}'
+    
+    
+    def _repr_html_(self):
         "HTML of this citation"
-        value = parse_xmd(
-            self._slide._app._citations_dict.get(self._key, f'Set citation for key {self._key!r} using `.set_citations` or [{self._key}]:&#96;citationvalue&#96; in markdown.'),
-            display_inline=False, rich_outputs = False
-            ).replace('<p>','',1)[::-1].replace('</p>','',1)[::-1] # Only replace first <p>
+        return self.value
         
-        return _HTML(f'''<span class = "citation" id="{self._key}">
+    @property
+    def value(self):
+        _value = self._slide._app._citations_dict.get(self._key, f'Set citation for key {self._key!r} using slides.set_citations or [{self._key}]:&#96;citation text&#96; in markdown.')
+        return f'''<span class = "citation" id="{self._key}">
             <a href="#{self._key}-back">
                 <sup style="color:var(--accent-color);">{self._id}</sup>
-            </a>{value}</span>''')
+            </a>{_value}</span>'''
         
         
 class Slides(BaseSlides):
@@ -77,19 +80,28 @@ class Slides(BaseSlides):
             self.widgets._notebook_dir = self.shell.starting_dir # This is must after shell is defined
             self.shell.register_magic_function(self.__slide, magic_kind='cell',magic_name='slide')
             self.shell.register_magic_function(self.__title, magic_kind='cell',magic_name='title')
-            self.shell.register_magic_function(self.notes.insert, magic_kind='line',magic_name='notes')
             self.shell.register_magic_function(self.__xmd, magic_kind='line_cell',magic_name='xmd')
             self.shell.user_ns['__Slides_Instance__'] = self
             self.user_ns = self.shell.user_ns #important for set_dir
             
-            # Override print function to display in order in slides
-            def pprint(*args, **kwargs):
-                "Displays object(s) inline with others in corrct order. args and kwargs are passed to builtin print."
-                with self.capture_std() as std:
-                    print(*args, **kwargs)
-                std.stdout.display() # Display at the end
+        # Override print function to display in order in slides
+        if self.shell.__class__.__name__ in ('ZMQInteractiveShell','Shell'): # Shell for Colab
+            import builtins
+            self.builtin_print = builtins.print # Save original print function otherwise it will throw a recursion error
+            def print(*args, **kwargs):
+                """Prints object(s) inline with others in corrct order. args and kwargs are passed to builtin `print`.
+                If `file` argument is not `sys.stdout`, then print is passed to given file."""
+
+                if 'file' in kwargs and kwargs['file'] != sys.stdout: # User should be able to redirect print to file
+                    return self.builtin_print(*args, **kwargs)
+
+                with capture_output() as captured:
+                    self.builtin_print(*args, **kwargs)
+
+                return self.raw(captured.stdout,className = 'CustomPrint').display() # Display at the end
+                # CustomPrint is used to avoid the print to be displayed when `with suppress_stdout` is used.
             
-            self.shell.user_ns['pprint'] = pprint
+            builtins.print = print
         
         self._citation_mode = 'global' # One of 'global', 'inline', 'footnote'
             
@@ -99,7 +111,7 @@ class Slides(BaseSlides):
         self._iterable = [] #self._collect_slides() # Collect internally
         self._nslides =  0 # Real number of slides
         self._max_index = 0 # Maximum index including frames
-        self._running_slide = None # For Notes, citations etc in markdown
+        self._running_slide = None # For Notes, citations etc in markdown, controlled in Slide class
         
         self.progress_slider = self.widgets.sliders.progress
         self.progress_slider.label = '0' # Set inital value, otherwise it does not capture screenshot if title only
@@ -123,6 +135,7 @@ class Slides(BaseSlides):
         - alert`cite&#96;key&#96;` to add citation to current slide
         - alert`[key]:&#96;citation content&#96;`  to add citation value, use these at start, so can be access in alert`cite&#96;key&#96;`
         - alert`citations&#96;citations title&#96;`  to add citations at end if `citation_mode = 'global'`.
+        - alert`include&#96;markdown_file.md&#96;` to include a file in markdown format. Useful to have citations in a separate file. (2.0.6+)
         - Triple dashes `---` is used to split markdown text in slides inside `from_markdown(start, file_or_str)` function.
         - Double dashes `--` is used to split markdown text in frames. (1.8.9+)
         
@@ -248,19 +261,28 @@ class Slides(BaseSlides):
         "Access current visible slide and use operations like insert, set_css etc."
         return self._iterable[self._slideindex]
     
+    @property
+    def running(self):
+        "Access slide currently being built. Useful inside frames decorator."
+        return self._running_slide
+    
     @property
     def citations(self):
-        "Get All citations."
+        "Get All citations as a tuple that can be passed to `write` function."
         # Need to filter unique keys across all slides
-        _all_citations = {}
-        for slide in self[:]:
-            _all_citations.update(slide.citations)
+        if self._citation_mode == 'global':
+            _all_citations = {}
+            for slide in self[:]:
+                _all_citations.update(slide._citations)
             
-        return _all_citations
+            return tuple(sorted(_all_citations.values(), key=lambda x: x._id))
+        
+        return ("No citations in 'inline' or 'footnote' mode",)
     
     def clear(self):
         "Clear all slides."
         self._slides_dict = {} # Clear slides
+        self._citations_dict = {} # Clear citations as well
         with _build_slide(self, '0'):
             with suppress(BaseException): # Create a clean title page with no previous toasts/css/animations etc.
                 self.parse_xmd('# Title Page', display_inline=True)
@@ -270,69 +292,50 @@ class Slides(BaseSlides):
     
     def cite(self, key):
         """Add citation in presentation, key should be a unique string and citation is text/markdown/HTML.
-        Citations corresponding to keys used can be created by `.set_citations` method.
+        Citations corresponding to keys used can be created by `.set_citations ` method.
+        Citation can be accessed by alert`Slides.citations` property and can be passed to `write` function.
         
         **New in 1.7.2**      
-        In Markdown(under `%%slide int -m` or in `from_markdown`), citations can be created by using alert`cite&#96;key&#96;` syntax and 
+        In Markdown (under `%%slide int -m` or in `from_markdown`), citations can be created by using alert`cite&#96;key&#96;` syntax and 
         can be set using alert`[key]:&#96;citationtext&#96;` syntax. If citation_mode is global, they can be shown using alert`citations&#96;citation title&#96;` syntax.
         
         """
+        if not self._running_slide:
+            raise RuntimeError('Citations can be added only inside a slide constructor!')
+        
         if self._citation_mode == 'inline':
             return utils.textbox(self._citations_dict.get(key,f'Set citation for key {key!r} using `.set_citations`'),left='initial',top='initial').value # Just write here
         
         this_slide = self._running_slide
         _cited = _Citation(slide = this_slide, key = key)
-        this_slide._citations[key] = _cited
-        
+        self._citations_dict[key] = self._citations_dict.get(key, f'Set citation for key {key!r} using slides.set_citations or [{key}]:&#96;citation text&#96; in markdown.') # This to ensure single run shows citation
         
         # Set _id for citation
         if self._citation_mode == 'footnote':
-            _cited._id = str(list(this_slide.citations.keys()).index(key) + 1) # Get index of key
+            _cited._id = str(list(this_slide._citations.keys()).index(key) + 1) # Get index of key
         else:
-            # Find number of citations created till now
-            prev_citations = {**self.citations, **this_slide.citations} # Current citations + previous ones
-            if key in prev_citations:
-                _cited._id = str(list(prev_citations.keys()).index(key) + 1)
+            prev_keys = list(self._citations_dict.keys())
+                    
+            if key in prev_keys:
+                _cited._id = str(prev_keys.index(key) + 1)
             else:
-                _cited._id = str(len(prev_citations)) 
+                _cited._id = str(len(prev_keys)) 
              
         # Return string otherwise will be on different place
         return f'<a href="#{key}"><sup id ="{key}-back" style="color:var(--accent-color);">{_cited._id}</sup></a>'
     
     def set_citations(self, citations_dict):
         "Set citations in presentation. citations_dict should be a dict of {key:value,...}"
-        self._citations_dict.update(citations_dict)
+        self._citations_dict.update({key:self.parse_xmd(value, display_inline=False, rich_outputs = False
+                        ).replace('<p>','',1)[::-1].replace('</p>','',1)[::-1] # Only replace first <p>
+                for key, value in citations_dict.items()})
+        
         if self._citation_mode == 'footnote':
             for slide in self[:]:
                 if slide.citations:
                     slide.update_display()
         else:
-            self.notify('Citations updated, please rerun the slide with references to see effect.')
-            
-    def citations_html(self,title='### References'): 
-        """Write all citations collected via `cite` method in the end of the presentation.
-        
-        **New in 1.7.2**      
-        In markdown (under `%%slide int -m` or in `from_markdown`), use `citations: citations title:` syntax.
-        """    
-        if self._citation_mode != 'global':
-            return self.html("p", "Citations are consumed per slide or inline.\n" 
-                "If you want to display them at the end, "
-                "use `citation_mode = 'global` during initialization of `Slides`.")
-            
-        _html = _HTML(self.parse_xmd(title + '\n',display_inline=False, rich_outputs = False))
-        
-        for citation in self.citations.values():
-            _html = _html + citation.html
-        
-        return _html
-        
-    def write_citations(self,title='### References'):
-        """Write all citations collected via `cite` method in the end of the presentation.
-        
-        **New in 1.7.2**      
-        In markdown (under `%%slide int -m` or in `from_markdown`), use `citations:citations title:` syntax."""
-        return self.citations_html(title = title).display()
+            self.notify('Citations updated, please rerun the slides with references to see effect.')
         
     def show(self, fix_buttons = False): 
         "Display Slides. If icons do not show, try with `fix_buttons=True`."
@@ -458,17 +461,6 @@ class Slides(BaseSlides):
         self._slides_dict = {k:v for k,v in self._slides_dict.items() if not k.startswith(number)} # Delete all frames too
         self.refresh()
         
-        
-    def set_slide_css(self,props_dict = {}):
-        """Set CCS to slide which is being built, props_dict is a dict of css properties in format {'selector': {'prop':'value',...},...}
-        'selector' for slide itself should be ''.
-        """
-        self._running_slide.set_css(props_dict)
-    
-    def set_overall_animation(self, main = 'slide_h',frame = 'slide_v'):
-        "Set animation for main and frame slides for all slides. For individual slides, use `self[index or key].set_animation/self.current.set_animation`"
-        self._running_slide.set_overall_animation(main = main, frame = frame)
-    
     # defining magics and context managers
     def __slide(self,line,cell):
         """Capture content of a cell as `slide`.
@@ -483,11 +475,6 @@ class Slides(BaseSlides):
             **New in 1.7.2**    
             Find special syntax to be used in markdown by `Slides.xmd_syntax`.
         
-        (1.7.7+) You can run a slide only once for long calculations.
-            ---------------- Cell ----------------
-            %%slide 3 -s
-            var = certain_long_calculation() # This will be run only once
-            
         (1.8.9+) If Markdown is separated by two dashes (--) on it's own line, multiple frames are created.
         Markdown before the first three underscores is written on all frames. This is equivalent to `@Slides.frames` decorator.
         """
@@ -495,13 +482,11 @@ class Slides(BaseSlides):
         if line and not line[0].isnumeric():
             raise ValueError(f'You should use %%slide integer >= 1 -m(optional), got {line}')
         
-        
         # NOTE: DO NOT bypass creating new slides with same old markdown, some varibale
         #      may be changed in any of the cells.
         
         slide_number_str = line[0] # First argument is slide number
         
-        
         if '-m' in line[1:]:
             _frames = re.split(r'^--$|^--\s+$',cell,flags = re.MULTILINE) # Split on --- or ---\s+
             if len(_frames) > 1:
@@ -514,17 +499,11 @@ class Slides(BaseSlides):
                 self._running_slide._markdown = _frame # Update markdown, # cell_code will be automatuically cleared in `self.frames`
             
         else: # Run even if already exists as it is user choice in Notebook, unlike markdown which loads from file
-            if '-s' in line[1:] and slide_number_str in self._slides_dict:
-                if self._running_slide._cell_code == cell:
-                    return # Do not run if cell is same as previous and -s is used
-            
             with _build_slide(self, slide_number_str, from_cell = True) as s:
                 self.shell.run_cell(cell) #  Enables citations etc.
             
             s._cell_code = cell # Update cell code
             s._markdown = '' # Reset markdown
-        
-        self._running_slide = None
                    
     
     @contextmanager
@@ -538,8 +517,6 @@ class Slides(BaseSlides):
         
         with _build_slide(self, f'{slide_number}', props_dict=props_dict, from_cell = False) as s:
             yield s # Useful to use later
-            
-        self._running_slide = None
         
     def __title(self,line,cell):
         "Turns to cell magic `title` to capture title"
@@ -615,7 +592,6 @@ class Slides(BaseSlides):
            
             # build_slide returns old slide with updated display if exists.
             with _build_slide(self, f'{slide_number}', props_dict= props_dict, from_cell = False, is_frameless = False) as this_slide:
-                self._running_slide = this_slide
                 self.write(self.format_css('.SlideArea',height = frame_height))
                 func(_new_objs[0]) # Main slide content
             
@@ -625,29 +601,21 @@ class Slides(BaseSlides):
             
             new_frames = []
             for i, obj in enumerate(_new_objs): # New frames
-                with capture_output() as captured:
-                    if i >= NFRAMES_OLD: # Add new frames
-                        new_slide = Slide(self, captured_output=captured, props_dict= props_dict)
-                        self._running_slide = new_slide
-                        new_slide._number = f'{slide_number}'
-                        new_frames.append(new_slide)
-                        
-                    else: # Update old frames
-                        self._running_slide = this_slide._frames[i] # Take same frame back
-                        new_frames.append(self._running_slide) # Take same frame back
-                    
-                    # Write content after taking back the frame or creating new frame
-                    
+                if i >= NFRAMES_OLD: # Add new frames
+                    new_slide = Slide(self, slide_number, props_dict= props_dict)
+                else: # Update old frames
+                    new_slide = this_slide._frames[i] # Take same frame back
+                
+                new_frames.append(new_slide)
+                
+                with new_slide._capture(assign = True) as captured:
                     self.write(self.format_css('.SlideArea',height = frame_height))
                     func(obj)
                 
-                self._running_slide._contents = captured.outputs # Update contents
-                self._running_slide._from_cell = False
-                self._running_slide._cell_code = ''    
+                new_slide._from_cell = False
+                new_slide._cell_code = ''    
                 
-                append_print_warning(captured = captured, append_to= new_frames[i]._contents)
                 
-            
             this_slide._frames = new_frames
             
             if len(this_slide._frames) != NFRAMES_OLD:
@@ -657,8 +625,6 @@ class Slides(BaseSlides):
             for s in this_slide._frames:
                 s.update_display()
             
-            self._running_slide = None
-            
         return _frames 
 
     def _collect_slides(self):
@@ -688,7 +654,7 @@ class Slides(BaseSlides):
             
         return tuple(slides_iterable)
     
-    def create(self, *slide_numbers):
+    def create(self, *slide_numbers, props_dict ={}):
         "Create empty slides with given slide numbers. If a slide already exists, it remains same. This is faster than creating one slide each time."
         new_slides = False
         for slide_number in slide_numbers:
@@ -696,8 +662,7 @@ class Slides(BaseSlides):
                 with capture_output() as captured:
                     self.write(f'### Slide-{slide_number}')
                 
-                self._slides_dict[f'{slide_number}'] = Slide(self, captured_output=captured)
-                self._slides_dict[f'{slide_number}']._number = f'{slide_number}'
+                self._slides_dict[f'{slide_number}'] = Slide(self, slide_number, captured_output=captured, props_dict= props_dict)
                 new_slides = True
         
         if new_slides:
@@ -707,19 +672,7 @@ class Slides(BaseSlides):
     
     def glassmorphic(self, image_src, opacity=0.75, blur_radius=50):
         "Adds glassmorphic effect to the background. `image_src` can be a url or a local image path. `opacity` and `blur_radius` are optional. (2.0.1+)"
-        if not image_src:
-            self.widgets.htmls.glass.value = '' # Hide glassmorphic
-            return None
-        
-        if not os.path.isfile(image_src):
-            raise FileNotFoundError(f'Image not found at {image_src!r}')
-        
-        self.widgets.htmls.glass.value = f"""<style>
-        {glass_css(opacity=opacity, blur_radius=blur_radius)}
-        </style>
-        {self.image(image_src,width='100%',zoomable=False)}
-        <div class="Front"></div>
-        """
+        return self.settings.set_glassmorphic(image_src, opacity = opacity, blur_radius = blur_radius)
 
 # Make available as Singleton Slides
 _private_instance = Slides() # Singleton in use namespace
@@ -729,22 +682,19 @@ class Slides:
     __doc__ = textwrap.dedent("""
     Interactive Slides in IPython Notebook. Only one instance can exist. 
     
-    All arguments are passed to corresponding methods in `ls.settings`, so you can use those methods to change settings as well.
+    All arguments are passed to corresponding methods in `slides.settings`, so you can use those methods to change settings as well.
     
-    Instead of builtin `print`, use `pprint` (1.5.9+) or `with capture_std` in slides use following to display printed content in correct order.
+    To suppress unwanted print from other libraries/functions (2.1.0+), use:
     ```python
-    with ls.capture_std() as std:
-        print('something')
-        function_that_prints_something()
-        display('Something') # Will be displayed here
-        ls.write(std.stdout) # Will be written here whatever printed above this line
-        
-    std.stdout.display() #ls.write(std.stdout)
+    with slides.suppress_stdout():
+        some_function_that_prints() # This will not be printed
+        print('This will not be printed either')
+        display('Something') # This will be printed
     ```
     
-    > `ls.demo` and `ls.docs` overwrite all previous slides.
+    > `slides.demo` and `slides.docs` overwrite all previous slides.
     
-    Aynthing with class name 'report-only' will not be displayed on slides, but appears in document when `ls.export.report` is called.
+    Aynthing with class name 'report-only' will not be displayed on slides, but appears in document when `slides.export.report` is called.
     This is useful to fill-in content in document that is not required in slides.
     
     Starting with 1.8, you can provide extensions at initialization time as a list to arguments `extensions`. See [PyMdownx](https://facelessuser.github.io/pymdown-extensions/extensions/arithmatex/) for useful extensions. `'pymdownx.arithmatex'` is a recommended extension to load Maths faster.
