@@ -94,19 +94,19 @@ def resolve_objs_on_slide(slide_instance,text_chunk):
         text_chunk = text_chunk.replace(f'cite`{match}`', slide_instance.cite(key), 1)
     
     # notes`This is a note for current slide`
-    all_matches = re.findall(r'notes\`(.*?)\`', text_chunk, flags = re.DOTALL)
+    all_matches = re.findall(r'notes\`(.*?)\`', text_chunk, flags = re.DOTALL | re.MULTILINE)
     for match in all_matches:
         slide_instance.notes.insert(match)
         text_chunk = text_chunk.replace(f'notes`{match}`', '', 1)
     
     # citations`This is citations title`
-    all_matches = re.findall(r'citations\`(.*?)\`', text_chunk, flags = re.DOTALL)
+    all_matches = re.findall(r'citations\`(.*?)\`', text_chunk, flags = re.DOTALL | re.MULTILINE)
     for match in all_matches:
-        citations = slide_instance.citations_html(title = match).value
-        text_chunk = text_chunk.replace(f'citations`{match}`', citations, 1)
+        repr_html = slide_instance.format_html([match, *slide_instance.citations]).value
+        text_chunk = text_chunk.replace(f'citations`{match}`', repr_html, 1)
     
     # [key]:`citation content`
-    all_matches = re.findall(r'\[(.*?)\]\:\`(.*?)\`', text_chunk, flags = re.DOTALL)
+    all_matches = re.findall(r'\[(.*?)\]\:\`(.*?)\`', text_chunk, flags = re.DOTALL | re.MULTILINE)
     citations = {}
     for match in all_matches:
         citations[match[0].strip()] = match[1]
@@ -226,8 +226,6 @@ class _ExtendedMarkdown(Markdown):
                 shell.run_cell(dedent_data) # Run after assigning it to variable, so can be accessed inside code too
             
             outputs = captured.outputs
-            from ._base.slide import append_print_warning # Avoid circular import
-            append_print_warning(captured=captured, append_to=outputs)
             return outputs
         
     def _sub_vars(self, html_output):
@@ -251,14 +249,14 @@ class _ExtendedMarkdown(Markdown):
         # Replace inline one argumnet functions
         from . import utils # Inside function to avoid circular import
         for func in _special_funcs.keys():
-            all_matches = re.findall(fr'{func}\`(.*?)\`', html_output, flags = re.DOTALL)
+            all_matches = re.findall(fr'{func}\`(.*?)\`', html_output, flags = re.DOTALL | re.MULTILINE)
             for match in all_matches:
                 _func = getattr(utils,func)
                 _out = _func(match).value if match else _func().value # If no argument, use default
                 html_output = html_output.replace(f'{func}`{match}`', _out, 1)
         
         # Replace columns after vars, so not to format their brackets
-        all_cols = re.findall(r'\|\|(.*?)\|\|(.*?)\|\|', html_output, flags = re.DOTALL) # Matches new line as well, useful for inline plots and big objects
+        all_cols = re.findall(r'\|\|(.*?)\|\|(.*?)\|\|', html_output, flags = re.DOTALL | re.MULTILINE) # Matches new line as well, useful for inline plots and big objects
         for cols in all_cols:
             _cols = ''.join(f'<div style="width:50%;">{self.convert(c)}</div>' for c in cols)
             _out = f'<div class="columns">{_cols}</div>'
@@ -271,7 +269,7 @@ class _ExtendedMarkdown(Markdown):
         
         
         # Replace colored text
-        all_matches = re.findall(r'color\[(.*?)\]\`(.*?)\`', html_output, flags = re.DOTALL)
+        all_matches = re.findall(r'color\[(.*?)\]\`(.*?)\`', html_output, flags = re.DOTALL | re.MULTILINE)
         for match in all_matches:
             kws = {'fg':None,'bg':None}
             if '_' in match[0]:
@@ -281,6 +279,14 @@ class _ExtendedMarkdown(Markdown):
             html_output = html_output.replace(f'color[{match[0]}]`{match[1]}`', utils.colored(match[1],**kws).value, 1)
         
         html_output = re.sub(r'^\^\^\^$', '</div>', html_output,flags=re.MULTILINE) # Close last block
+        
+        # Run an included file
+        all_matches = re.findall(r'include\`(.*?)\`', html_output, flags = re.DOTALL)
+        for match in all_matches:
+            with open(match,'r') as f:
+                repr_html = self.parse(f.read(),display_inline=False,rich_outputs=False)
+            html_output = html_output.replace(f'include`{match}`', repr_html, 1)
+        
         return html_output # return in main scope
             
 
